@@ -37,7 +37,7 @@ _records = [
     Country(u"Benin", "BJ", "BEN", "204"),
     Country(u"Bermuda", "BM", "BMU", "060"),
     Country(u"Bhutan", "BT", "BTN", "064"),
-    Country(u"Bolivia", "BO", "BOL", "068"),
+    Country(u"Bolivia, Plurinational State of", "BO", "BOL", "068"),
     Country(u"Bonaire, Sint Eustatius and Saba", "BQ", "BES", "535"),
     Country(u"Bosnia and Herzegovina", "BA", "BIH", "070"),
     Country(u"Botswana", "BW", "BWA", "072"),
@@ -196,7 +196,8 @@ _records = [
     Country(u"Russian Federation", "RU", "RUS", "643"),
     Country(u"Rwanda", "RW", "RWA", "646"),
     Country(u"Saint Barthélemy", "BL", "BLM", "652"),
-    Country(u"Saint Helena", "SH", "SHN", "654"),
+    Country(u"Saint Helena, Ascension and Tristan da Cunha",
+            "SH", "SHN", "654"),
     Country(u"Saint Kitts and Nevis", "KN", "KNA", "659"),
     Country(u"Saint Lucia", "LC", "LCA", "662"),
     Country(u"Saint Martin (French part)", "MF", "MAF", "663"),
@@ -252,7 +253,7 @@ _records = [
     Country(u"Uruguay", "UY", "URY", "858"),
     Country(u"Uzbekistan", "UZ", "UZB", "860"),
     Country(u"Vanuatu", "VU", "VUT", "548"),
-    Country(u"Venezuela", "VE", "VEN", "862"),
+    Country(u"Venezuela, Bolivarian Republic of", "VE", "VEN", "862"),
     Country(u"Viet Nam", "VN", "VNM", "704"),
     Country(u"Virgin Islands, British", "VG", "VGB", "092"),
     Country(u"Virgin Islands, U.S.", "VI", "VIR", "850"),
